@@ -1,19 +1,7 @@
 /*
-  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef FILTERIMPORTERBASE_H
@@ -26,6 +14,10 @@
 
 namespace MailImporter {
 class FilterInfo;
+/**
+ * @brief The FilterImporterBase class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILIMPORTER_EXPORT FilterImporterBase
 {
 public:
@@ -38,7 +30,7 @@ public:
     Q_REQUIRED_RESULT virtual int countDuplicates() const;
     Q_REQUIRED_RESULT virtual QString topLevelFolder() const;
 protected:
-    MailImporter::FilterInfo *mInfo = nullptr;
+    MailImporter::FilterInfo *const mInfo;
 };
 }
 #endif // FILTERIMPORTERBASE_H
