@@ -1,26 +1,19 @@
-/***************************************************************************
-                          filter_mbox.cxx  -  mbox mail import
-                             -------------------
-    begin                : Sat Apr 5 2003
-    copyright            : (C) 2003 by Laurence Anderson
-    email                : l.d.anderson@warwick.ac.uk
- ***************************************************************************/
+/*
+  filtermbox.cpp  -  mbox mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2003 Laurence Anderson <l.d.anderson@warwick.ac.uk>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-#include <KLocalizedString>
-#include <qfiledialog.h>
-#include <QTemporaryFile>
-#include "mailimporter_debug.h"
 
 #include "filtermbox.h"
+#include "mailimporter_debug.h"
+
+#include <KLocalizedString>
+
+#include <QFileDialog>
+#include <QTemporaryFile>
 
 using namespace MailImporter;
 
@@ -42,7 +35,8 @@ FilterMBox::~FilterMBox()
 
 void FilterMBox::import()
 {
-    const QStringList filenames = QFileDialog::getOpenFileNames(filterInfo()->parentWidget(), QString(), QDir::homePath(), i18n("mbox Files (*.mbox)"));
+    const QStringList filenames = QFileDialog::getOpenFileNames(filterInfo()->parentWidget(),
+                                                                QString(), QDir::homePath(), QStringLiteral("%1 (*.mbox)").arg(i18n("mbox Files")));
     importMails(filenames);
 }
 
@@ -116,7 +110,9 @@ void FilterMBox::importMails(const QStringList &filenames)
                 first_msg = false;
 
                 if (tmp.size() > 0) {
-                    importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage());
+                    if (!importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                        filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+                    }
                 } else {
                     qCWarning(MAILIMPORTER_LOG) << "Message size is 0 bytes, not importing it.";
                 }
