@@ -1,19 +1,10 @@
-/***************************************************************************
-                  filter_opera.cxx  -  Opera mail import
-                             -------------------
-    begin                : Januar 26 2005
-    copyright            : (C) 2005 by Danny Kukawka
-    email                : danny.kukawka@web.de
- ***************************************************************************/
+/*
+  filteropera.cpp  -  Opera mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filteropera.h"
 
@@ -129,7 +120,9 @@ void FilterOpera::importBox(const QDir &importDir, const QStringList &files, con
                 tmp.flush();
                 first_msg = false;
 
-                importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage());
+                if (!importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                    filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+                }
                 int currentPercentage = (int)(((float)operaArchiv.pos() / filenameInfo.size()) * 100);
                 filterInfo()->setCurrent(currentPercentage);
 
